@@ -1,7 +1,10 @@
 package Regexp::Storable;
 
+our $VERSION = '0.04';
+
 package Regexp;
 
+
 sub STORABLE_freeze {
   my $serialized = substr($_[0], rindex($_[0],':')+1, -1);
   return $serialized;
@@ -9,6 +12,7 @@ sub STORABLE_freeze {
 
 sub STORABLE_thaw {
   my ( $original, $cloning, $thaw ) = @_;
+  return unless $thaw;
   my $final = qr/$thaw/;
   Regexp::Copy::re_copy($final, $original);
 }
